@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -80,7 +81,7 @@ class Automation:
             raise InvalidParameterError("Bad parameter: source must be an str")
         if "destination" in params and not isinstance(params["destination"], str):
             raise InvalidParameterError("Bad parameter: destination must be an str")
-        if "destinations" in params and not isinstance(params["destinations"], list):
+        if "destinations" in params and not isinstance(params["destinations"], builtins.list):
             raise InvalidParameterError("Bad parameter: destinations must be an list")
         if "destination_replace_from" in params and not isinstance(params["destination_replace_from"], str):
             raise InvalidParameterError("Bad parameter: destination_replace_from must be an str")
@@ -100,7 +101,7 @@ class Automation:
             raise InvalidParameterError("Bad parameter: name must be an str")
         if "trigger" in params and not isinstance(params["trigger"], str):
             raise InvalidParameterError("Bad parameter: trigger must be an str")
-        if "trigger_actions" in params and not isinstance(params["trigger_actions"], list):
+        if "trigger_actions" in params and not isinstance(params["trigger_actions"], builtins.list):
             raise InvalidParameterError("Bad parameter: trigger_actions must be an list")
         if "trigger_action_path" in params and not isinstance(params["trigger_action_path"], str):
             raise InvalidParameterError("Bad parameter: trigger_action_path must be an str")
@@ -133,15 +134,15 @@ class Automation:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `automation`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `automation`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `automation`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `automation`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `automation`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `automation`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `automation`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `automation`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `automation`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `automation`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `automation`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `automation`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `automation`.
 #   automation - string - DEPRECATED: Type of automation to filter by. Use `filter[automation]` instead.
 def list(params = None, options = None):
     if not isinstance(params, dict):
@@ -220,7 +221,7 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: source must be an str")
     if "destination" in params and not isinstance(params["destination"], str):
         raise InvalidParameterError("Bad parameter: destination must be an str")
-    if "destinations" in params and not isinstance(params["destinations"], list):
+    if "destinations" in params and not isinstance(params["destinations"], builtins.list):
         raise InvalidParameterError("Bad parameter: destinations must be an list")
     if "destination_replace_from" in params and not isinstance(params["destination_replace_from"], str):
         raise InvalidParameterError("Bad parameter: destination_replace_from must be an str")
@@ -242,7 +243,7 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: name must be an str")
     if "trigger" in params and not isinstance(params["trigger"], str):
         raise InvalidParameterError("Bad parameter: trigger must be an str")
-    if "trigger_actions" in params and not isinstance(params["trigger_actions"], list):
+    if "trigger_actions" in params and not isinstance(params["trigger_actions"], builtins.list):
         raise InvalidParameterError("Bad parameter: trigger_actions must be an list")
     if "trigger_action_path" in params and not isinstance(params["trigger_action_path"], str):
         raise InvalidParameterError("Bad parameter: trigger_action_path must be an str")
@@ -285,7 +286,7 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: source must be an str")
     if "destination" in params and not isinstance(params["destination"], str):
         raise InvalidParameterError("Bad parameter: destination must be an str")
-    if "destinations" in params and not isinstance(params["destinations"], list):
+    if "destinations" in params and not isinstance(params["destinations"], builtins.list):
         raise InvalidParameterError("Bad parameter: destinations must be an list")
     if "destination_replace_from" in params and not isinstance(params["destination_replace_from"], str):
         raise InvalidParameterError("Bad parameter: destination_replace_from must be an str")
@@ -307,7 +308,7 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: name must be an str")
     if "trigger" in params and not isinstance(params["trigger"], str):
         raise InvalidParameterError("Bad parameter: trigger must be an str")
-    if "trigger_actions" in params and not isinstance(params["trigger_actions"], list):
+    if "trigger_actions" in params and not isinstance(params["trigger_actions"], builtins.list):
         raise InvalidParameterError("Bad parameter: trigger_actions must be an list")
     if "trigger_action_path" in params and not isinstance(params["trigger_action_path"], str):
         raise InvalidParameterError("Bad parameter: trigger_action_path must be an str")
