@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from builtins import open as builtin_open
 from datetime import datetime
@@ -183,79 +184,6 @@ class File:
         with builtin_open(output_file, 'wb') as file:
             self.download_content(file)
 
-def open(path, mode = "r", options = None):
-    if not isinstance(options, dict):
-        options = {}
-    file = File(path, mode, options)
-    
-    if "w" in mode:
-        if "b" in mode:
-            file.io_obj = io.BytesIO()
-        else:
-            file.io_obj = io.StringIO()
-
-    if "r" in mode:
-        if "b" in mode:
-            file.io_obj = io.BytesIO()
-        else:
-            file.io_obj = io.StringIO()
-    file.closed = False
-    return file
-
-def upload_chunks(io, path, options, upload = None, etags = None):
-    if not etags:
-        etags = []
-    bytes_written = 0
-    while True:
-        headers = { "part": 1 } if not upload else { "ref": upload.ref, "part": upload.part_number + 1 }
-        upload = begin_upload(path, headers, options)[0]
-        buf = io.read(upload.partsize)
-        if buf == b'' or buf == "":  # Empty bytearray means EOF for BytesIO, Empty String means EOF for StringIO
-            return (upload, etags, bytes_written)
-        if buf is not None:  # None means no data but io still open
-            bytes_written += len(buf)
-            response = Api.api_client().send_remote_request(upload.http_method, upload.upload_uri, { "Content-Length": str(len(buf)) }, buf)
-            if "ETag" in response.headers:
-                etags.append({ "etag": response.headers["ETag"].strip('"'), "part": upload.part_number })
-
-def upload_file(path, destination = None, options = None):
-    if not isinstance(options, dict):
-        options = {}
-    pth = Path(path)
-    stat = pth.stat()
-    with builtin_open(path, 'rb') as local_file:
-        if destination is None:
-            destination = pth.name
-        upload, etags, _bytes_written = upload_chunks(local_file, destination, options)
-
-        params = {
-            "action": "end",
-            "etags": etags,
-            "provided_mtime": datetime.utcfromtimestamp(stat.st_mtime).isoformat(),
-            "ref": upload.ref,
-            "size": stat.st_size
-        }
-
-        create(destination, params, options)
-
-def download_file(path, local_path = None, options = None):
-    if not isinstance(options, dict):
-        options = {}
-    if local_path is None:
-        local_path = Path(path).name
-    return File(path, {}, options).download_file(local_path)
-
-def find(path, params = None, options = None):
-    if not isinstance(params, dict):
-        params = {}
-    if not isinstance(options, dict):
-        options = {}
-    params["action"] = "stat"
-    return download(path, params, options)
-
-def from_path(path):
-    return metadata(path)
-
     # Download file
     #
     # Parameters:
@@ -323,28 +251,6 @@ def from_path(path):
 
     def destroy(self, params = None):
         self.delete(params)
-    # Return metadata for file/folder
-    #
-    # Parameters:
-    #   preview_size - string - Request a preview size.  Can be `small` (default), `large`, `xlarge`, or `pdf`.
-    #   with_previews - boolean - Include file preview information?
-    #   with_priority_color - boolean - Include file priority color information?
-    def metadata(self, params = None):
-        if not isinstance(params, dict):
-            params = {}
-
-        if hasattr(self, "path") and self.path:
-            params['path'] = self.path
-        else:
-            raise MissingParameterError("Current object doesn't have a path")
-        if "path" not in params:
-            raise MissingParameterError("Parameter missing: path")
-        if "path" in params and not isinstance(params["path"], str):
-            raise InvalidParameterError("Bad parameter: path must be an str")
-        if "preview_size" in params and not isinstance(params["preview_size"], str):
-            raise InvalidParameterError("Bad parameter: preview_size must be an str")
-        response, _options = Api.send_request("GET", "/file_actions/metadata/{path}".format(path=params['path']), params, self.options)
-        return response.data
 
     # Copy file/folder
     #
@@ -401,6 +307,7 @@ def from_path(path):
     #   parts - int64 - How many parts to fetch?
     #   ref - string -
     #   restart - int64 - File byte offset to restart from.
+    #   size - int64 - Total bytes of file being uploaded (include bytes being retained if appending/restarting).
     #   with_rename - boolean - Allow file rename instead of overwrite?
     def begin_upload(self, params = None):
         if not isinstance(params, dict):
@@ -422,10 +329,11 @@ def from_path(path):
             raise InvalidParameterError("Bad parameter: ref must be an str")
         if "restart" in params and not isinstance(params["restart"], int):
             raise InvalidParameterError("Bad parameter: restart must be an int")
+        if "size" in params and not isinstance(params["size"], int):
+            raise InvalidParameterError("Bad parameter: size must be an int")
         response, _options = Api.send_request("POST", "/file_actions/begin_upload/{path}".format(path=params['path']), params, self.options)
         return response.data
 
-
     def save(self):
         new_obj = create(self.path, self.get_attributes(), self.options)
         self.set_attributes(new_obj.get_attributes())
@@ -538,13 +446,12 @@ def delete(path, params = None, options = None):
 def destroy(path, params = None, options = None):
     delete(path, params, options)
 
-# Return metadata for file/folder
-#
 # Parameters:
+#   path (required) - string - Path to operate on.
 #   preview_size - string - Request a preview size.  Can be `small` (default), `large`, `xlarge`, or `pdf`.
 #   with_previews - boolean - Include file preview information?
 #   with_priority_color - boolean - Include file priority color information?
-def metadata(path, params = None, options = None):
+def find(path, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
     if not isinstance(options, dict):
@@ -559,6 +466,9 @@ def metadata(path, params = None, options = None):
     response, options = Api.send_request("GET", "/file_actions/metadata/{path}".format(path=params['path']), params, options)
     return File(response.data, options)
 
+def get(path, params = None, options = None):
+    find(path, params, options)
+
 # Copy file/folder
 #
 # Parameters:
@@ -610,6 +520,7 @@ def move(path, params = None, options = None):
 #   parts - int64 - How many parts to fetch?
 #   ref - string -
 #   restart - int64 - File byte offset to restart from.
+#   size - int64 - Total bytes of file being uploaded (include bytes being retained if appending/restarting).
 #   with_rename - boolean - Allow file rename instead of overwrite?
 def begin_upload(path, params = None, options = None):
     if not isinstance(params, dict):
@@ -627,10 +538,85 @@ def begin_upload(path, params = None, options = None):
         raise InvalidParameterError("Bad parameter: ref must be an str")
     if "restart" in params and not isinstance(params["restart"], int):
         raise InvalidParameterError("Bad parameter: restart must be an int")
+    if "size" in params and not isinstance(params["size"], int):
+        raise InvalidParameterError("Bad parameter: size must be an int")
     if "path" not in params:
         raise MissingParameterError("Parameter missing: path")
     response, options = Api.send_request("POST", "/file_actions/begin_upload/{path}".format(path=params['path']), params, options)
     return [ FileUploadPart(entity_data, options) for entity_data in response.data ]
 
+def open(path, mode = "r", options = None):
+    if not isinstance(options, dict):
+        options = {}
+    file = File(path, mode, options)
+    
+    if "w" in mode:
+        if "b" in mode:
+            file.io_obj = io.BytesIO()
+        else:
+            file.io_obj = io.StringIO()
+
+    if "r" in mode:
+        if "b" in mode:
+            file.io_obj = io.BytesIO()
+        else:
+            file.io_obj = io.StringIO()
+    file.closed = False
+    return file
+
+def upload_chunks(io, path, options, upload = None, etags = None):
+    if not etags:
+        etags = []
+    bytes_written = 0
+    while True:
+        headers = { "part": 1 } if not upload else { "ref": upload.ref, "part": upload.part_number + 1 }
+        upload = begin_upload(path, headers, options)[0]
+        buf = io.read(upload.partsize)
+        if buf == b'' or buf == "":  # Empty bytearray means EOF for BytesIO, Empty String means EOF for StringIO
+            return (upload, etags, bytes_written)
+        if buf is not None:  # None means no data but io still open
+            bytes_written += len(buf)
+            response = Api.api_client().send_remote_request(upload.http_method, upload.upload_uri, { "Content-Length": str(len(buf)) }, buf)
+            if "ETag" in response.headers:
+                etags.append({ "etag": response.headers["ETag"].strip('"'), "part": upload.part_number })
+
+def upload_file(path, destination = None, options = None):
+    if not isinstance(options, dict):
+        options = {}
+    pth = Path(path)
+    stat = pth.stat()
+    with builtin_open(path, 'rb') as local_file:
+        if destination is None:
+            destination = pth.name
+        upload, etags, _bytes_written = upload_chunks(local_file, destination, options)
+
+        params = {
+            "action": "end",
+            "etags": etags,
+            "provided_mtime": datetime.utcfromtimestamp(stat.st_mtime).isoformat(),
+            "ref": upload.ref,
+            "size": stat.st_size
+        }
+
+        create(destination, params, options)
+
+def download_file(path, local_path = None, options = None):
+    if not isinstance(options, dict):
+        options = {}
+    if local_path is None:
+        local_path = Path(path).name
+    return File(path, {}, options).download_file(local_path)
+
+def find(path, params = None, options = None):
+    if not isinstance(params, dict):
+        params = {}
+    if not isinstance(options, dict):
+        options = {}
+    params["action"] = "stat"
+    return download(path, params, options)
+
+def from_path(path):
+    return metadata(path)
+
 def new(*args, **kwargs):
     return File(*args, **kwargs)
\ No newline at end of file
