@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -35,7 +36,6 @@ class RemoteServer:
         'azure_blob_storage_account': None,     # string - Azure Blob Storage Account name
         'azure_blob_storage_container': None,     # string - Azure Blob Storage Container name
         's3_compatible_bucket': None,     # string - S3-compatible Bucket name
-        's3_compatible_region': None,     # string - S3-compatible Bucket name
         's3_compatible_endpoint': None,     # string - S3-compatible endpoint
         'enable_dedicated_ips': None,     # boolean - `true` if remote server only accepts connections from dedicated IPs
         'aws_access_key': None,     # string - AWS Access Key.
@@ -108,7 +108,6 @@ class RemoteServer:
     #   azure_blob_storage_account - string - Azure Blob Storage Account name
     #   azure_blob_storage_container - string - Azure Blob Storage Container name
     #   s3_compatible_bucket - string - S3-compatible Bucket name
-    #   s3_compatible_region - string - S3-compatible Bucket name
     #   s3_compatible_endpoint - string - S3-compatible endpoint
     #   enable_dedicated_ips - boolean - `true` if remote server only accepts connections from dedicated IPs
     #   s3_compatible_access_key - string - S3-compatible access key
@@ -197,8 +196,6 @@ class RemoteServer:
             raise InvalidParameterError("Bad parameter: azure_blob_storage_container must be an str")
         if "s3_compatible_bucket" in params and not isinstance(params["s3_compatible_bucket"], str):
             raise InvalidParameterError("Bad parameter: s3_compatible_bucket must be an str")
-        if "s3_compatible_region" in params and not isinstance(params["s3_compatible_region"], str):
-            raise InvalidParameterError("Bad parameter: s3_compatible_region must be an str")
         if "s3_compatible_endpoint" in params and not isinstance(params["s3_compatible_endpoint"], str):
             raise InvalidParameterError("Bad parameter: s3_compatible_endpoint must be an str")
         if "s3_compatible_access_key" in params and not isinstance(params["s3_compatible_access_key"], str):
@@ -234,7 +231,7 @@ class RemoteServer:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 def list(params = None, options = None):
     if not isinstance(params, dict):
@@ -306,7 +303,6 @@ def get(id, params = None, options = None):
 #   azure_blob_storage_account - string - Azure Blob Storage Account name
 #   azure_blob_storage_container - string - Azure Blob Storage Container name
 #   s3_compatible_bucket - string - S3-compatible Bucket name
-#   s3_compatible_region - string - S3-compatible Bucket name
 #   s3_compatible_endpoint - string - S3-compatible endpoint
 #   enable_dedicated_ips - boolean - `true` if remote server only accepts connections from dedicated IPs
 #   s3_compatible_access_key - string - S3-compatible access key
@@ -388,8 +384,6 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_container must be an str")
     if "s3_compatible_bucket" in params and not isinstance(params["s3_compatible_bucket"], str):
         raise InvalidParameterError("Bad parameter: s3_compatible_bucket must be an str")
-    if "s3_compatible_region" in params and not isinstance(params["s3_compatible_region"], str):
-        raise InvalidParameterError("Bad parameter: s3_compatible_region must be an str")
     if "s3_compatible_endpoint" in params and not isinstance(params["s3_compatible_endpoint"], str):
         raise InvalidParameterError("Bad parameter: s3_compatible_endpoint must be an str")
     if "s3_compatible_access_key" in params and not isinstance(params["s3_compatible_access_key"], str):
@@ -437,7 +431,6 @@ def create(params = None, options = None):
 #   azure_blob_storage_account - string - Azure Blob Storage Account name
 #   azure_blob_storage_container - string - Azure Blob Storage Container name
 #   s3_compatible_bucket - string - S3-compatible Bucket name
-#   s3_compatible_region - string - S3-compatible Bucket name
 #   s3_compatible_endpoint - string - S3-compatible endpoint
 #   enable_dedicated_ips - boolean - `true` if remote server only accepts connections from dedicated IPs
 #   s3_compatible_access_key - string - S3-compatible access key
@@ -522,8 +515,6 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: azure_blob_storage_container must be an str")
     if "s3_compatible_bucket" in params and not isinstance(params["s3_compatible_bucket"], str):
         raise InvalidParameterError("Bad parameter: s3_compatible_bucket must be an str")
-    if "s3_compatible_region" in params and not isinstance(params["s3_compatible_region"], str):
-        raise InvalidParameterError("Bad parameter: s3_compatible_region must be an str")
     if "s3_compatible_endpoint" in params and not isinstance(params["s3_compatible_endpoint"], str):
         raise InvalidParameterError("Bad parameter: s3_compatible_endpoint must be an str")
     if "s3_compatible_access_key" in params and not isinstance(params["s3_compatible_access_key"], str):
